(function(blocks, blockEditor, i18n, element, components, _) {
    var el = element.createElement;

    blocks.registerBlockType('ncms/header-html', {
        title: 'Header HTML',
        icon: 'editor-kitchensink',
        category: 'common',

        attributes: {
            blockValue: {
                type: 'string',
                source: 'meta',
                meta: 'ncms_header_html'
            }
        },

        edit: function(props) {
            var className = props.className;
            var setAttributes = props.setAttributes;
 
            function updateBlockValue(blockValue) {
                setAttributes({blockValue});
            }

            return el(
                'div',
                {className: className},
                el(blockEditor.PlainText, {
                    label: 'Header HTML',
                    placeholder: 'Header HTML',
                    value: props.attributes.blockValue,
                    onChange: updateBlockValue
                })
            );
        },
 
        // No information saved to the block
        // Data is saved to post meta via attributes
        save: function() {
            return null;
        },

        supports: {
            multiple: false
        }
    });

    blocks.registerBlockType('ncms/sidebar', {
        title: 'Sidebar',
        icon: 'index-card',
        category: 'common',

        attributes: {
            sidebar: {
                type: 'string',
                source: 'meta',
                meta: 'ncms_sidebar'
            }
        },

        edit: function(props) {
            var className = props.className;
            var setAttributes = props.setAttributes;
 
            function updateSidebar(sidebar) {
                setAttributes({sidebar});
            }

            return el(
                'div',
                {className: className},
                el(components.SelectControl, {
                    options: [
                        {label: '(none)', value: ''},
                        {label: 'BuildMaster', value: 'buildmaster'},
                        {label: 'Company', value: 'company'},
                        {label: 'General', value: 'general'},
                        {label: 'Otter', value: 'otter'},
                        {label: 'ProGet', value: 'proget'},
                        {label: 'Romp', value: 'romp'},
                        {label: 'Support', value: 'support'},
                        {label: 'Training', value: 'training'},
                        {label: 'UPack', value: 'upack'}
                    ],
                    label: 'Sidebar',
                    value: props.attributes.sidebar,
                    onChange: updateSidebar
                })
            );
        },
 
        // No information saved to the block
        // Data is saved to post meta via attributes
        save: function() {
            return null;
        },

        supports: {
            multiple: false
        }
    });

    blocks.registerBlockType('ncms/kb-id', {
        title: 'Knowledge Base ID',
        icon: 'index-card',
        category: 'common',

        attributes: {
            kbID: {
                type: 'integer',
                source: 'meta',
                meta: 'ncms_kb_id'
            }
        },

        edit: function(props) {
            var className = props.className;
            var setAttributes = props.setAttributes;
 
            function updateValue(kbID) {
                setAttributes({kbID});
            }

            return el(
                'div',
                {className: className},
                el(components.TextControl, {
                    label: 'Knowledge Base ID',
                    type: 'number',
                    value: props.attributes.kbID,
                    onChange: updateValue
                })
            );
        },
 
        // No information saved to the block
        // Data is saved to post meta via attributes
        save: function() {
            return null;
        },

        supports: {
            multiple: false
        }
    });

    blocks.registerBlockType('ncms/docs-url', {
        title: 'Docs URL',
        icon: 'code-standards',
        category: 'common',

        attributes: {
            docsUrl: {
                type: 'string',
                source: 'meta',
                meta: 'ncms_docs_url'
            }
        },

        edit: function(props) {
            var className = props.className;
            var setAttributes = props.setAttributes;
 
            function updateValue(docsUrl) {
                setAttributes({docsUrl});
            }

            return el(
                'div',
                {className: className},
                el(components.TextControl, {
                    label: 'Docs URL',
                    type: 'string',
                    value: props.attributes.docsUrl,
                    onChange: updateValue
                })
            );
        },
 
        // No information saved to the block
        // Data is saved to post meta via attributes
        save: function() {
            return null;
        },

        supports: {
            multiple: false
        }
    });
})(
    window.wp.blocks,
    window.wp.blockEditor,
    window.wp.i18n,
    window.wp.element,
    window.wp.components,
    window._
);
